@@ -753,38 +753,44 @@ class CalibrationClientByDetectorTest(ModuleBase, unittest.TestCase):
         # Calibration Constant Version info
         resp_pdus = resp['data']
 
-        exp_pdu0 = {'id': -3,
-                    'physical_name': 'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE',
-                    'detector_type_id': -1, 'detector_id': -2,
-                    'karabo_da': 'TEST_DAQ_DA_03'}
+        exp_pdu_pos1 = {
+            'id': -3,
+            'physical_name': 'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE',
+            'detector_type_id': -1, 'detector_id': -2,
+            'karabo_da': 'TEST_DAQ_DA_03'}
 
-        assert resp_pdus[0]['id'] == exp_pdu0['id']
-        assert resp_pdus[0]['physical_name'] == exp_pdu0['physical_name']
-        assert resp_pdus[0]['detector_type_id'] == exp_pdu0['detector_type_id']
-        assert resp_pdus[0]['detector_id'] == exp_pdu0['detector_id']
-        assert resp_pdus[0]['karabo_da'] == exp_pdu0['karabo_da']
+        assert resp_pdus[2]['id'] == exp_pdu_pos1['id']
+        assert resp_pdus[2]['physical_name'] == exp_pdu_pos1['physical_name']
+        assert resp_pdus[2]['detector_type_id'] == exp_pdu_pos1[
+            'detector_type_id']
+        assert resp_pdus[2]['detector_id'] == exp_pdu_pos1['detector_id']
+        assert resp_pdus[2]['karabo_da'] == exp_pdu_pos1['karabo_da']
 
-        exp_pdu1 = {'id': -2,
-                    'physical_name': 'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE',
-                    'detector_type_id': -1, 'detector_id': -2,
-                    'karabo_da': 'TEST_DAQ_DA_02'}
+        exp_pdu_pos2 = {
+            'id': -2,
+            'physical_name': 'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE',
+            'detector_type_id': -1, 'detector_id': -2,
+            'karabo_da': 'TEST_DAQ_DA_02'}
 
-        assert resp_pdus[1]['id'] == exp_pdu1['id']
-        assert resp_pdus[1]['physical_name'] == exp_pdu1['physical_name']
-        assert resp_pdus[1]['detector_type_id'] == exp_pdu1['detector_type_id']
-        assert resp_pdus[1]['detector_id'] == exp_pdu1['detector_id']
-        assert resp_pdus[1]['karabo_da'] == exp_pdu1['karabo_da']
+        assert resp_pdus[1]['id'] == exp_pdu_pos2['id']
+        assert resp_pdus[1]['physical_name'] == exp_pdu_pos2['physical_name']
+        assert resp_pdus[1]['detector_type_id'] == exp_pdu_pos2[
+            'detector_type_id']
+        assert resp_pdus[1]['detector_id'] == exp_pdu_pos2['detector_id']
+        assert resp_pdus[1]['karabo_da'] == exp_pdu_pos2['karabo_da']
 
-        exp_pdu2 = {'id': -1,
-                    'physical_name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
-                    'detector_type_id': -1, 'detector_id': -2,
-                    'karabo_da': 'TEST_DAQ_DA_01'}
+        exp_pdu_pos3 = {
+            'id': -1,
+            'physical_name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+            'detector_type_id': -1, 'detector_id': -2,
+            'karabo_da': 'TEST_DAQ_DA_01'}
 
-        assert resp_pdus[2]['id'] == exp_pdu2['id']
-        assert resp_pdus[2]['physical_name'] == exp_pdu2['physical_name']
-        assert resp_pdus[2]['detector_type_id'] == exp_pdu2['detector_type_id']
-        assert resp_pdus[2]['detector_id'] == exp_pdu2['detector_id']
-        assert resp_pdus[2]['karabo_da'] == exp_pdu2['karabo_da']
+        assert resp_pdus[0]['id'] == exp_pdu_pos3['id']
+        assert resp_pdus[0]['physical_name'] == exp_pdu_pos3['physical_name']
+        assert resp_pdus[0]['detector_type_id'] == exp_pdu_pos3[
+            'detector_type_id']
+        assert resp_pdus[0]['detector_id'] == exp_pdu_pos3['detector_id']
+        assert resp_pdus[0]['karabo_da'] == exp_pdu_pos3['karabo_da']
 
 
 if __name__ == '__main__':
